@@ -3,7 +3,7 @@ use warnings;
 package Alien::gperf;
 
 # ABSTRACT: Perl distribution for GNU gperf
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use parent 'Alien::Base';
 
@@ -20,7 +20,7 @@ Alien::gperf - Perl distribution for GNU gperf
     use Alien::gperf;
     use Env qw( @PATH );
 
-    unshift @ENV, Alien::gperf->bin_dir;
+    unshift @PATH, Alien::gperf->bin_dir;
     system gperf, '--version';
 
 =head1 DESCRIPTION
